@@ -9,6 +9,7 @@ use Term::ANSIColor qw( colored );
 use AnyEvent::Handle;
 use AnyEvent::Socket;
 use Carp qw( croak );
+use DDC;
 
 sub logmsg {
   print colored($_[0],'yellow')."\n";
@@ -17,67 +18,17 @@ sub logmsg {
 sub in {
   print colored(' IN ','yellow');
   print colored('[','blue');
-  data($_[0]);
+  pc($_[0]);
   print colored(']','blue')."\n";
 }
 
 sub out {
   print colored('OUT ','yellow');
   print colored('[','blue');
-  data($_[0]);
+  pc($_[0]);
   print colored(']','blue')."\n";
 }
 
-our %ord = (qw(
-    0 NUL
-    1 SOH
-    2 STX
-    3 ETX
-    4 EOT
-    5 ENQ
-    6 ACK
-    7 BEL
-    8 BS
-    9 TAB
-   10 LF
-   11 VT
-   12 FF
-   13 CR
-   14 SO
-   15 SI 
-   16 DLE
-   17 DC1
-   18 DC2
-   19 DC3
-   20 DC4
-   21 NAK
-   22 SYN
-   23 ETB
-   24 CAN
-   25 EM
-   26 SUB
-   27 ESC
-   28 FS
-   29 GS
-   30 RS
-   31 US
-  127 DEL
-));
-
-sub data {
-  my @chars = split(//,$_[0]);
-  for my $char (@chars) {
-    my $chr = ord($char);
-    if (defined $ord{$chr}) {
-      print colored('['.$ord{$chr}.']','bright_red');
-    } elsif ($char =~ /[ -~]/) {
-      print colored($char,'bright_white');
-    } else {
-      print colored('<'.unpack('H*',$char).'>', 'bright_cyan');        
-    }
-  }
-}
-
 sub create_proxy {
   my ( $port, $remote_host, $remote_port ) = @_;
 
@@ -189,7 +140,7 @@ tcpproxy.pl - Simple TCP proxy for debugging connections
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -218,12 +169,6 @@ version 0.004
   OUT [a]
   OUT [t]
   OUT [c]
-  OUT [a]
-  OUT [t]
-  OUT [c]
-  OUT [a]
-  OUT [t]
-  OUT [c]
   OUT [[CR]<00>]
    IN [[CR][LF]]
    IN [Last login: Fri Dec  5 01:58:51 CET 2014 from localhost on pts/7[CR][LF]Linux bigbird 3.2.0-4-amd64 #1 SMP Debian 3.2.63-2+deb7u1 x86_64[CR][LF][CR][LF]The programs included with the Debian GNU/Linux system are free software;[CR][LF]the exact distribution terms for each program are described in the[CR][LF]individual files in /usr/share/doc/*/copyright.[CR][LF][CR][LF]Debian GNU/Linux comes with ABSOLUTELY NO WARRANTY, to the extent[CR][LF]permitted by applicable law.[CR][LF]]
